pub struct Within { /* fields omitted */ }Expand description
Within has a custom tolerance for equalling thirteen.
radius is how far value can be from 13 to equal 13. That makes sense, right?
Performs copy-assignment from source. Read more
Formats the value using the given formatter. Read more
Returns true if self is thirteen.
impl<T> Any for T where
T: 'static + ?Sized,
Immutably borrows from an owned value. Read more
Mutably borrows from an owned value. Read more
impl<T, U> Into<U> for T where
U: From<T>,
The resulting type after obtaining ownership.
Creates owned data from borrowed data, usually by cloning. Read more
🔬 This is a nightly-only experimental API. (toowned_clone_into)
recently added
Uses borrowed data to replace owned data, usually by cloning. Read more
The type returned in the event of a conversion error.
The type returned in the event of a conversion error.